
## CATO-CLI - mutation.sites.removeSocketAddOnCard:
[Click here](https://api.catonetworks.com/documentation/#mutation-removeSocketAddOnCard) for documentation on this operation.

### Usage for mutation.sites.removeSocketAddOnCard:

`catocli mutation sites removeSocketAddOnCard -h`

`catocli mutation sites removeSocketAddOnCard <json>`

`catocli mutation sites removeSocketAddOnCard "$(cat < removeSocketAddOnCard.json)"`

`catocli mutation sites removeSocketAddOnCard '{"removeSocketAddOnCardInput": {"expansionSlotNumbers": {"expansionSlotNumbers": "enum(SocketAddOnExpansionSlotNumber)"}, "siteRefInput": {"by": {"by": "enum(ObjectRefBy)"}, "input": {"input": "String"}}}}'`

#### Operation Arguments for mutation.sites.removeSocketAddOnCard ####
`accountId` [ID] - (required) N/A 
`removeSocketAddOnCardInput` [RemoveSocketAddOnCardInput] - (required) N/A 
